==> nomachine-7.6.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXTools.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXTools::BEGIN{package NXTools;no warnings;require Common::NXPaths;do{
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x50\x61\x74\x68\x73"->import};}sub 
NXTools::getWindowsSystemPath{package NXTools;no warnings;(my $systemPath=(""));
if ((defined ($ENV{
"\x53\x79\x73\x74\x65\x6d\x44\x69\x72\x65\x63\x74\x6f\x72\x79"})and (length (
$ENV{"\x53\x79\x73\x74\x65\x6d\x44\x69\x72\x65\x63\x74\x6f\x72\x79"})>
(0x07a0+ 7681-0x25a1)))){($systemPath=$ENV{
"\x53\x79\x73\x74\x65\x6d\x44\x69\x72\x65\x63\x74\x6f\x72\x79"});}elsif ((
defined ($ENV{"\x57\x69\x6e\x44\x69\x72"})and (length ($ENV{
"\x57\x69\x6e\x44\x69\x72"})>(0x0457+ 4524-0x1603)))){($systemPath=(($ENV{
"\x57\x69\x6e\x44\x69\x72"}.$GLOBAL::DIRECTORY_SLASH).
"\x53\x79\x73\x74\x65\x6d\x33\x32"));}elsif ((defined ($ENV{
"\x53\x79\x73\x74\x65\x6d\x52\x6f\x6f\x74"})and (length ($ENV{
"\x53\x79\x73\x74\x65\x6d\x52\x6f\x6f\x74"})>(0x1216+ 4007-0x21bd)))){(
$systemPath=(($ENV{"\x53\x79\x73\x74\x65\x6d\x52\x6f\x6f\x74"}.
$GLOBAL::DIRECTORY_SLASH)."\x53\x79\x73\x74\x65\x6d\x33\x32"));}elsif ((defined 
($ENV{"\x53\x79\x73\x74\x65\x6d\x44\x72\x69\x76\x65"})and (length ($ENV{
"\x53\x79\x73\x74\x65\x6d\x44\x72\x69\x76\x65"})>(0x0372+ 1477-0x0937)))){(
$systemPath=(((($ENV{"\x53\x79\x73\x74\x65\x6d\x44\x72\x69\x76\x65"}.
$GLOBAL::DIRECTORY_SLASH)."\x57\x69\x6e\x64\x6f\x77\x73").
$GLOBAL::DIRECTORY_SLASH)."\x53\x79\x73\x74\x65\x6d\x33\x32"));}elsif ((defined 
($ENV{"\x48\x4f\x4d\x45\x44\x52\x49\x56\x45"})and (length ($ENV{
"\x48\x4f\x4d\x45\x44\x52\x49\x56\x45"})>(0x1003+ 931-0x13a6)))){($systemPath=((
(($ENV{"\x48\x4f\x4d\x45\x44\x52\x49\x56\x45"}.$GLOBAL::DIRECTORY_SLASH).
"\x57\x69\x6e\x64\x6f\x77\x73").$GLOBAL::DIRECTORY_SLASH).
"\x53\x79\x73\x74\x65\x6d\x33\x32"));}else{Logger::debug (
"\x67\x65\x74\x57\x69\x6e\x64\x6f\x77\x73\x53\x79\x73\x74\x65\x6d\x50\x61\x74\x68\x28\x29\x3a\x20\x75\x6e\x61\x62\x6c\x65\x20\x74\x6f\x20\x73\x65\x74\x20\x70\x61\x74\x68"
);return ((""));}Logger::debug (((
"\x67\x65\x74\x57\x69\x6e\x64\x6f\x77\x73\x53\x79\x73\x74\x65\x6d\x50\x61\x74\x68\x28\x29\x3a\x20\x73\x65\x74\x20\x70\x61\x74\x68\x20\x74\x6f\x20\x5b"
.$systemPath)."\x5d"));return ($systemPath);}sub 
NXTools::getPortAgentMBaseOnDisplay{package NXTools;no warnings;(my $display=
shift (@_));(my $port=($display+getAgentMirrorPortOffset ()));return ($port);}
sub NXTools::getAgentMirrorPortOffset{package NXTools;no warnings;return (
$GLOBAL::PORT_DISPLAY_MIRROR_DELTA);}sub NXTools::getLang{package NXTools;no 
warnings;(my $envLang=libnxh::NXTransGetEnvironment ("\x4c\x41\x4e\x47"));if ((
$envLang eq (""))){Logger::debug2 (
"\x4c\x41\x4e\x47\x20\x65\x6e\x76\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2c\x20\x6c\x65\x74\x27\x73\x20\x74\x72\x79\x20\x2e\x64\x6d\x72\x63\x2e"
);($envLang=getLangFromDmrcFile ());if (($envLang eq (""))){Logger::debug2 (
"\x4c\x41\x4e\x47\x20\x65\x6e\x76\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2c\x20\x67\x65\x74\x74\x69\x6e\x67\x20\x6c\x61\x6e\x67\x75\x61\x67\x65\x20\x66\x72\x6f\x6d\x20\x64\x61\x65\x6d\x6f\x6e\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2e"
);($envLang=getServerDaemonLang ());}}return ($envLang);}sub 
NXTools::getLangFromDmrcFile{package NXTools;no warnings;(my $filename=(
Common::NXPaths::getEffectiveUserHomeDirectory ()."\x2f\x2e\x64\x6d\x72\x63"));(my $DMRC_FILE_HANDLE
=main::nxopen ($filename,$NXBits::O_RDONLY,(0x23b9+ 416-0x2559),{"\x41\x4c\x4c",
"\x73\x69\x6c\x65\x6e\x74"}));(my $errorstring=libnxh::NXGetErrorString ());my (
$line);(my $found=(""));if ((not (defined ($DMRC_FILE_HANDLE)))){Logger::debug (
(((
"\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x74\x65\x72\x6d\x69\x6e\x65\x20\x4c\x41\x4e\x47\x20\x62\x61\x73\x65\x64\x20\x6f\x6e\x20\x74\x68\x65\x20\x66\x69\x6c\x65\x3a\x20"
.$filename)."\x3a\x20").$errorstring));return ((""));}else{while (
main::nxreadLine ($DMRC_FILE_HANDLE,(\$line))){chomp ($line);if (($line=~ /^Language=(.*)$/ )
){($found=$1);last;}}main::nxclose ($DMRC_FILE_HANDLE);}return ($found);}sub 
NXTools::getServerDaemonLang{package NXTools;no warnings;return (
$GLOBAL::parameters{"\x65\x6e\x76\x4c\x61\x6e\x67"});}sub NXTools::setWidth{
package NXTools;no warnings;(my $refTable=shift (@_));(my $name=shift (@_));(my $value
=shift (@_));if (($$refTable{$name}<length ($value))){($$refTable{$name}=length 
($value));}}sub NXTools::printWidth{package NXTools;no warnings;(my $refTable=
shift (@_));(my $name=shift (@_));(my $value=shift (@_));(my $width=($$refTable{
$name}+(0x0d52+ 2722-0x17f3)));(my $message=sprintf ((((("\x25\x2d".$width).
"\x2e").$width)."\x73"),$value));if ((main::nxwrite (main::nxgetSTDOUT (),
$message)==(-(0x09a4+ 2723-0x1446)))){return ((-(0x11b0+ 5382-0x26b5)));}}sub 
NXTools::printMark{package NXTools;no warnings;(my $refTable=shift (@_));(my $name
=shift (@_));(my $value=shift (@_));(my $width=($$refTable{$name}+
(0x10c9+ 4185-0x2121)));(my $message=sprintf ((((("\x25\x2d".$width)."\x2e").
$width)."\x73"),("\x2d" x $$refTable{$name})));if ((main::nxwrite (
main::nxgetSTDOUT (),$message)==(-(0x0a8c+ 4716-0x1cf7)))){return ((-
(0x1953+ 1117-0x1daf)));}}sub NXTools::printTable{package NXTools;no warnings;(my $ref_labels
=shift (@_));(my $ref_values=shift (@_));(my (%table)=());for ((my $i=
(0x0933+ 3571-0x1726));($i<@$ref_labels);(++$i)){setWidth ((\%table),$i,
@$ref_labels[$i]);}foreach my $value (values (%$ref_values)){for ((my $i=
(0x17a5+ 1492-0x1d79));($i<@$ref_labels);(++$i)){(my $name=@$ref_labels[$i]);
setWidth ((\%table),$i,$$value{$name});}}for ((my $i=(0x0b22+ 2818-0x1624));($i<
@$ref_labels);(++$i)){printWidth ((\%table),$i,@$ref_labels[$i]);}if ((
main::nxwrite (main::nxgetSTDOUT (),"\x0a")==(-(0x0eb8+ 586-0x1101)))){return ((
-(0x1986+ 1514-0x1f6f)));}for ((my $i=(0x0b67+ 4543-0x1d26));($i<@$ref_labels);(
++$i)){if (printMark ((\%table),$i)){return ((-(0x00da+  48-0x0109)));}}if ((
main::nxwrite (main::nxgetSTDOUT (),"\x0a")==(-(0x0e37+ 1323-0x1361)))){return (
(-(0x17eb+ 3468-0x2576)));}foreach my $key (sort (keys (%$ref_values))){(my $value
=$$ref_values{$key});for ((my $i=(0x0671+ 5161-0x1a9a));($i<@$ref_labels);(++$i)
){(my $name=@$ref_labels[$i]);if (printWidth ((\%table),$i,$$value{$name})){
return ((-(0x052f+ 4400-0x165e)));}}if ((main::nxwrite (main::nxgetSTDOUT (),
"\x0a")==(-(0x099b+ 5016-0x1d32)))){return ((-(0x11db+ 461-0x13a7)));}}if ((
main::nxwrite (main::nxgetSTDOUT (),"\x0a")==(-(0x1baf+ 1661-0x222b)))){return (
(-(0x041a+ 3557-0x11fe)));}return ((0x0010+ 1358-0x055e));}package NXTools;no 
warnings;"\x3f\x3f\x3f";

==> nomachine-7.7.4-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXTools.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXTools::BEGIN{package NXTools;no warnings;require Common::NXPaths;do{
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x50\x61\x74\x68\x73"->import};}sub 
NXTools::getWindowsSystemPath{package NXTools;no warnings;(my $systemPath=(""));
if ((defined ($ENV{
"\x53\x79\x73\x74\x65\x6d\x44\x69\x72\x65\x63\x74\x6f\x72\x79"})and (length (
$ENV{"\x53\x79\x73\x74\x65\x6d\x44\x69\x72\x65\x63\x74\x6f\x72\x79"})>
(0x036b+ 4691-0x15be)))){($systemPath=$ENV{
"\x53\x79\x73\x74\x65\x6d\x44\x69\x72\x65\x63\x74\x6f\x72\x79"});}elsif ((
defined ($ENV{"\x57\x69\x6e\x44\x69\x72"})and (length ($ENV{
"\x57\x69\x6e\x44\x69\x72"})>(0x0192+ 1345-0x06d3)))){($systemPath=(($ENV{
"\x57\x69\x6e\x44\x69\x72"}.$GLOBAL::DIRECTORY_SLASH).
"\x53\x79\x73\x74\x65\x6d\x33\x32"));}elsif ((defined ($ENV{
"\x53\x79\x73\x74\x65\x6d\x52\x6f\x6f\x74"})and (length ($ENV{
"\x53\x79\x73\x74\x65\x6d\x52\x6f\x6f\x74"})>(0x058c+ 2194-0x0e1e)))){(
$systemPath=(($ENV{"\x53\x79\x73\x74\x65\x6d\x52\x6f\x6f\x74"}.
$GLOBAL::DIRECTORY_SLASH)."\x53\x79\x73\x74\x65\x6d\x33\x32"));}elsif ((defined 
($ENV{"\x53\x79\x73\x74\x65\x6d\x44\x72\x69\x76\x65"})and (length ($ENV{
"\x53\x79\x73\x74\x65\x6d\x44\x72\x69\x76\x65"})>(0x0ad9+ 3167-0x1738)))){(
$systemPath=(((($ENV{"\x53\x79\x73\x74\x65\x6d\x44\x72\x69\x76\x65"}.
$GLOBAL::DIRECTORY_SLASH)."\x57\x69\x6e\x64\x6f\x77\x73").
$GLOBAL::DIRECTORY_SLASH)."\x53\x79\x73\x74\x65\x6d\x33\x32"));}elsif ((defined 
($ENV{"\x48\x4f\x4d\x45\x44\x52\x49\x56\x45"})and (length ($ENV{
"\x48\x4f\x4d\x45\x44\x52\x49\x56\x45"})>(0x01f5+ 5433-0x172e)))){($systemPath=(
((($ENV{"\x48\x4f\x4d\x45\x44\x52\x49\x56\x45"}.$GLOBAL::DIRECTORY_SLASH).
"\x57\x69\x6e\x64\x6f\x77\x73").$GLOBAL::DIRECTORY_SLASH).
"\x53\x79\x73\x74\x65\x6d\x33\x32"));}else{Logger::debug (
"\x67\x65\x74\x57\x69\x6e\x64\x6f\x77\x73\x53\x79\x73\x74\x65\x6d\x50\x61\x74\x68\x28\x29\x3a\x20\x75\x6e\x61\x62\x6c\x65\x20\x74\x6f\x20\x73\x65\x74\x20\x70\x61\x74\x68"
);return ((""));}Logger::debug (((
"\x67\x65\x74\x57\x69\x6e\x64\x6f\x77\x73\x53\x79\x73\x74\x65\x6d\x50\x61\x74\x68\x28\x29\x3a\x20\x73\x65\x74\x20\x70\x61\x74\x68\x20\x74\x6f\x20\x5b"
.$systemPath)."\x5d"));return ($systemPath);}sub 
NXTools::getPortAgentMBaseOnDisplay{package NXTools;no warnings;(my $display=
shift (@_));(my $port=($display+getAgentMirrorPortOffset ()));return ($port);}
sub NXTools::getAgentMirrorPortOffset{package NXTools;no warnings;return (
$GLOBAL::PORT_DISPLAY_MIRROR_DELTA);}sub NXTools::getLang{package NXTools;no 
warnings;(my $envLang=libnxh::NXTransGetEnvironment ("\x4c\x41\x4e\x47"));if ((
$envLang eq (""))){Logger::debug2 (
"\x4c\x41\x4e\x47\x20\x65\x6e\x76\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2c\x20\x6c\x65\x74\x27\x73\x20\x74\x72\x79\x20\x2e\x64\x6d\x72\x63\x2e"
);($envLang=getLangFromDmrcFile ());if (($envLang eq (""))){Logger::debug2 (
"\x4c\x41\x4e\x47\x20\x65\x6e\x76\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2c\x20\x67\x65\x74\x74\x69\x6e\x67\x20\x6c\x61\x6e\x67\x75\x61\x67\x65\x20\x66\x72\x6f\x6d\x20\x64\x61\x65\x6d\x6f\x6e\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2e"
);($envLang=getServerDaemonLang ());}}return ($envLang);}sub 
NXTools::getLangFromDmrcFile{package NXTools;no warnings;(my $filename=(
Common::NXPaths::getEffectiveUserHomeDirectory ()."\x2f\x2e\x64\x6d\x72\x63"));(my $DMRC_FILE_HANDLE
=main::nxopen ($filename,$NXBits::O_RDONLY,(0x0816+ 6429-0x2133),{"\x41\x4c\x4c"
,"\x73\x69\x6c\x65\x6e\x74"}));(my $errorstring=libnxh::NXGetErrorString ());my (
$line);(my $found=(""));if ((not (defined ($DMRC_FILE_HANDLE)))){Logger::debug (
(((
"\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x74\x65\x72\x6d\x69\x6e\x65\x20\x4c\x41\x4e\x47\x20\x62\x61\x73\x65\x64\x20\x6f\x6e\x20\x74\x68\x65\x20\x66\x69\x6c\x65\x3a\x20"
.$filename)."\x3a\x20").$errorstring));return ((""));}else{while (
main::nxreadLine ($DMRC_FILE_HANDLE,(\$line))){chomp ($line);if (($line=~ /^Language=(.*)$/ )
){($found=$1);last;}}main::nxclose ($DMRC_FILE_HANDLE);}return ($found);}sub 
NXTools::getServerDaemonLang{package NXTools;no warnings;return (
$GLOBAL::parameters{"\x65\x6e\x76\x4c\x61\x6e\x67"});}sub NXTools::setWidth{
package NXTools;no warnings;(my $refTable=shift (@_));(my $name=shift (@_));(my $value
=shift (@_));if (($$refTable{$name}<length ($value))){($$refTable{$name}=length 
($value));}}sub NXTools::printWidth{package NXTools;no warnings;(my $refTable=
shift (@_));(my $name=shift (@_));(my $value=shift (@_));(my $width=($$refTable{
$name}+(0x0092+ 7456-0x1db1)));(my $message=sprintf ((((("\x25\x2d".$width).
"\x2e").$width)."\x73"),$value));if ((main::nxwrite (main::nxgetSTDOUT (),
$message)==(-(0x0897+ 5670-0x1ebc)))){return ((-(0x1104+ 1549-0x1710)));}}sub 
NXTools::printMark{package NXTools;no warnings;(my $refTable=shift (@_));(my $name
=shift (@_));(my $value=shift (@_));(my $width=($$refTable{$name}+
(0x02bd+ 7999-0x21fb)));(my $message=sprintf ((((("\x25\x2d".$width)."\x2e").
$width)."\x73"),("\x2d" x $$refTable{$name})));if ((main::nxwrite (
main::nxgetSTDOUT (),$message)==(-(0x0fbc+ 4450-0x211d)))){return ((-
(0x1436+ 1641-0x1a9e)));}}sub NXTools::printTable{package NXTools;no warnings;(my $ref_labels
=shift (@_));(my $ref_values=shift (@_));(my (%table)=());for ((my $i=
(0x1699+ 1647-0x1d08));($i<@$ref_labels);(++$i)){setWidth ((\%table),$i,
@$ref_labels[$i]);}foreach my $value (values (%$ref_values)){for ((my $i=
(0x13ff+ 3127-0x2036));($i<@$ref_labels);(++$i)){(my $name=@$ref_labels[$i]);
setWidth ((\%table),$i,$$value{$name});}}for ((my $i=(0x02ef+ 6374-0x1bd5));($i<
@$ref_labels);(++$i)){printWidth ((\%table),$i,@$ref_labels[$i]);}if ((
main::nxwrite (main::nxgetSTDOUT (),"\x0a")==(-(0x0496+ 4163-0x14d8)))){return (
(-(0x0dcc+ 4671-0x200a)));}for ((my $i=(0x06cb+ 1038-0x0ad9));($i<@$ref_labels);
(++$i)){if (printMark ((\%table),$i)){return ((-(0x21fc+ 373-0x2370)));}}if ((
main::nxwrite (main::nxgetSTDOUT (),"\x0a")==(-(0x01b2+ 2167-0x0a28)))){return (
(-(0x029c+ 7734-0x20d1)));}foreach my $key (sort (keys (%$ref_values))){(my $value
=$$ref_values{$key});for ((my $i=(0x2130+ 1131-0x259b));($i<@$ref_labels);(++$i)
){(my $name=@$ref_labels[$i]);if (printWidth ((\%table),$i,$$value{$name})){
return ((-(0x0d63+ 775-0x1069)));}}if ((main::nxwrite (main::nxgetSTDOUT (),
"\x0a")==(-(0x1336+ 3218-0x1fc7)))){return ((-(0x0052+ 6971-0x1b8c)));}}if ((
main::nxwrite (main::nxgetSTDOUT (),"\x0a")==(-(0x1483+ 3268-0x2146)))){return (
(-(0x2021+ 1181-0x24bd)));}return ((0x1862+ 1466-0x1e1c));}package NXTools;no 
warnings;"\x3f\x3f\x3f";
